extract_box_payload_bytes_async

Function extract_box_payload_bytes_async 

pub async fn extract_box_payload_bytes_async<R>(
    reader: &mut R,
    parent: Option<&BoxInfo>,
    path: BoxPath,
) -> Result<Vec<Vec<u8>>, ExtractError>
where R: AsyncReadSeek,
Available on crate feature async only.
Extracts every box that matches path through the additive Tokio-based async surface and returns each matched payload as exact on-disk bytes.