pub async fn extract_boxes_payload_bytes_async<R>(
reader: &mut R,
parent: Option<&BoxInfo>,
paths: &[BoxPath],
) -> Result<Vec<Vec<u8>>, ExtractError>where
R: AsyncReadSeek,Available on crate feature
async only.Expand description
Extracts every box that matches any path in paths through the additive Tokio-based async
surface and returns each matched payload as exact on-disk bytes.