Available on crate feature
async only.Expand description
Tokio-based async I/O traits for the additive library-side async surface. Tokio-based async I/O traits for the library-side async surface.
The existing sync APIs remain the default path in mp4forge. The first async rollout is
intentionally limited to seekable library readers and writers such as Tokio file handles or
in-memory buffers. Later queue-backed follow-ons can also use the forward-only async reader
and writer aliases in this module when a surface can operate progressively without seeks. The
CLI continues to use the sync surface.
Traits
- Async
Read - Tokio async read trait used by the library-side async surface. Reads bytes from a source.
- Async
Read Forward - Async reader alias for forward-only library inputs.
- Async
Read Seek - Async reader alias for seekable library inputs.
- Async
Seek - Tokio async seek trait used by the library-side async surface. Seek bytes asynchronously.
- Async
Write - Tokio async write trait used by the library-side async surface. Writes bytes asynchronously.
- Async
Write Forward - Async writer alias for forward-only library outputs.
- Async
Write Seek - Async writer alias for seekable library outputs.