File-summary helpers built on the extraction and box layers. File-summary helpers built on the extraction and box layers, with byte-slice convenience entry points for in-memory probe flows.
Structs
- AacProfile
Info - AAC profile details derived from an
esdsdescriptor stream. - Ac3Codec
Details - Parsed AC-3 decoder configuration details.
- Av1Codec
Details - Parsed AV1 decoder configuration details.
- AvcCodec
Details - Parsed AVC decoder configuration details.
- AvcDecoder
Config Info - Summary of AVC decoder configuration attached to a video track.
- Chunk
Info - Expanded chunk placement information.
- Clean
Aperture Info - Clean-aperture values parsed from
clap. - Codec
Detailed Probe Info - Additive detailed probe summary that extends
DetailedProbeInfowith codec-specific configuration details. - Codec
Detailed Track Info - Additive per-track summary that extends
DetailedTrackInfowith parsed codec-specific configuration. - Color
Info - Declared color information parsed from
colr. - Content
Light Level Info - Content-light-level metadata parsed from
CoLL. - Declared
Bitrate Info - Declared buffering and bitrate values parsed from
btrt. - Detailed
Probe Info - Additive detailed probe summary that extends
ProbeInfowithout changing its public shape. - Detailed
Track Info - Additive per-track summary that extends
TrackInfowith richer sample-entry details. - Edit
List Entry - One edit-list entry from
elst. - Extended
Media Characteristics Probe Info - Additive detailed probe summary that extends
MediaCharacteristicsProbeInfowith extra typed visual sample-entry metadata. - Extended
Media Characteristics Track Info - Additive per-track summary that extends
MediaCharacteristicsTrackInfowith extra typed visual sample-entry metadata. - Field
Order Info - Declared field-order hint parsed from
fiel. - Hevc
Codec Details - Parsed HEVC decoder configuration details.
- Mastering
Display Info - Mastering-display metadata parsed from
SmDm. - Media
Characteristics Probe Info - Additive detailed probe summary that extends
CodecDetailedProbeInfowith media characteristics already parsed by the crate. - Media
Characteristics Track Info - Additive per-track summary that extends
DetailedTrackInfowith parsed codec and media characteristics. - Mp4Audio
Codec Details - Parsed MPEG-4 audio decoder configuration details.
- Mp4a
Info - Summary of MP4A decoder configuration attached to an audio track.
- Opus
Codec Details - Parsed Opus decoder configuration details.
- PcmCodec
Details - Parsed PCM configuration details.
- Pixel
Aspect Ratio Info - Declared pixel aspect ratio parsed from
pasp. - Probe
Info - High-level summary of one MP4 file.
- Probe
Options - Additive controls for eager probe expansion.
- Protection
Scheme Info - Protection-scheme summary derived from
schm. - Sample
Info - Expanded sample timing and size information.
- Segment
Info - Summary of one fragmented-media segment.
- Text
Subtitle Codec Details - Parsed text subtitle sample-entry details.
- Track
Info - Summary of one logical media track.
- Track
Media Characteristics - Media characteristics derived from stable sample-entry side boxes such as
btrt,colr,pasp, andfiel. - Track
Visual Metadata - Additional typed visual sample-entry metadata parsed from boxes that were added after the
original
TrackMediaCharacteristicsshape was stabilized. - VpCodec
Details - Parsed VP8 or VP9 decoder configuration details.
- WebVtt
Codec Details - Parsed WebVTT sample-entry details.
- XmlSubtitle
Codec Details - Parsed XML subtitle sample-entry details.
Enums
- Probe
Error - Errors raised while probing files or derived codec summaries.
- Track
Codec - Coarse codec classification used by the probe surface.
- Track
Codec Details - Parsed codec-specific configuration for one recognized track family.
- Track
Codec Family - Normalized codec family derived from the sample entry or protected original format.
Functions
- average_
sample_ bitrate - Returns the average bitrate implied by
samplesin the supplied timescale. - average_
segment_ bitrate - Returns the average bitrate implied by
segmentsfortrack_id. - detect_
aac_ effective_ sample_ rate - Detects the effective AAC sample rate signaled by one
esdsdescriptor stream. - detect_
aac_ profile - Detects the AAC object profile exposed by an
esdsdescriptor stream. - find_
idr_ frames - Finds sample indices whose AVC payload contains an IDR NAL unit.
- find_
idr_ frames_ async async - Finds sample indices whose AVC payload contains an IDR NAL unit through the additive Tokio- based async surface.
- max_
sample_ bitrate - Returns the maximum rolling-window bitrate implied by
samples. - max_
segment_ bitrate - Returns the maximum per-segment bitrate implied by
segmentsfortrack_id. - normalized_
codec_ family_ name - Returns the additive codec-family label used by detailed reporting.
- probe
- Probes a file and returns the backwards-compatible coarse movie, track, and fragment summary.
- probe_
async async - Probes a file through the additive Tokio-based async surface and returns the backwards-compatible coarse movie, track, and fragment summary.
- probe_
bytes - Probes an in-memory MP4 byte slice and returns the coarse movie, track, and fragment summary.
- probe_
bytes_ with_ options - Probes an in-memory MP4 byte slice with additive expansion controls and returns the coarse movie, track, and fragment summary.
- probe_
codec_ detailed - Probes a file and returns an additive detailed summary with parsed codec-specific configuration when it is available.
- probe_
codec_ detailed_ async async - Probes a file through the additive Tokio-based async surface and returns an additive detailed summary with parsed codec-specific configuration when it is available.
- probe_
codec_ detailed_ bytes - Probes an in-memory MP4 byte slice and returns the additive codec-detailed summary.
- probe_
codec_ detailed_ bytes_ with_ options - Probes an in-memory MP4 byte slice with additive expansion controls and returns the codec-detailed summary.
- probe_
codec_ detailed_ with_ options - Probes a file with additive expansion controls and returns the codec-detailed summary.
- probe_
codec_ detailed_ with_ options_ async async - Probes a file through the additive Tokio-based async surface with expansion controls and returns the codec-detailed summary.
- probe_
detailed - Probes a file and returns an additive detailed movie, track, and fragment summary.
- probe_
detailed_ async async - Probes a file through the additive Tokio-based async surface and returns an additive detailed movie, track, and fragment summary.
- probe_
detailed_ bytes - Probes an in-memory MP4 byte slice and returns the additive detailed summary.
- probe_
detailed_ bytes_ with_ options - Probes an in-memory MP4 byte slice with additive expansion controls and returns the detailed summary.
- probe_
detailed_ with_ options - Probes a file with additive expansion controls and returns the detailed movie, track, and fragment summary.
- probe_
detailed_ with_ options_ async async - Probes a file through the additive Tokio-based async surface with expansion controls and returns the detailed movie, track, and fragment summary.
- probe_
extended_ media_ characteristics - Probes a file and returns an additive summary with parsed codec, media characteristics, and extra typed visual sample-entry metadata.
- probe_
extended_ media_ characteristics_ async async - Probes a file through the additive Tokio-based async surface and returns an additive summary with parsed codec, media characteristics, and extra typed visual sample-entry metadata.
- probe_
extended_ media_ characteristics_ bytes - Probes an in-memory MP4 byte slice and returns the extended media-characteristics summary.
- probe_
extended_ media_ characteristics_ bytes_ with_ options - Probes an in-memory MP4 byte slice with additive expansion controls and returns the extended media-characteristics summary.
- probe_
extended_ media_ characteristics_ with_ options - Probes a file with additive expansion controls and returns the extended media-characteristics summary.
- probe_
extended_ media_ characteristics_ with_ options_ async async - Probes a file through the additive Tokio-based async surface with expansion controls and returns the extended media-characteristics summary.
- probe_
fra - Legacy fragmented-file probe entry point that currently aliases
probe. - probe_
fra_ async async - Legacy fragmented-file probe entry point through the additive Tokio-based async surface.
- probe_
fra_ bytes - Legacy fragmented-file probe entry point for in-memory MP4 bytes.
- probe_
fra_ codec_ detailed - Legacy fragmented-file codec-detailed probe entry point that currently aliases
probe_codec_detailed. - probe_
fra_ codec_ detailed_ async async - Legacy fragmented-file codec-detailed probe entry point through the additive Tokio-based async surface.
- probe_
fra_ codec_ detailed_ bytes - Legacy fragmented-file codec-detailed probe entry point for in-memory MP4 bytes.
- probe_
fra_ detailed - Legacy fragmented-file detailed probe entry point that currently aliases
probe_detailed. - probe_
fra_ detailed_ async async - Legacy fragmented-file detailed probe entry point through the additive Tokio-based async surface.
- probe_
fra_ detailed_ bytes - Legacy fragmented-file detailed probe entry point for in-memory MP4 bytes.
- probe_
fra_ media_ characteristics - Legacy fragmented-file media-characteristics probe entry point that currently aliases
probe_media_characteristics. - probe_
fra_ media_ characteristics_ async async - Legacy fragmented-file media-characteristics probe entry point through the additive Tokio-based async surface.
- probe_
fra_ media_ characteristics_ bytes - This currently aliases
probe_media_characteristics_bytesfor callers that already use the fragmented-file helper naming. - probe_
media_ characteristics - Probes a file and returns an additive summary with parsed codec and media characteristics.
- probe_
media_ characteristics_ async async - Probes a file through the additive Tokio-based async surface and returns an additive summary with parsed codec and media characteristics.
- probe_
media_ characteristics_ bytes - Probes an in-memory MP4 byte slice and returns the additive media-characteristics summary.
- probe_
media_ characteristics_ bytes_ with_ options - Probes an in-memory MP4 byte slice with additive expansion controls and returns the media-characteristics summary.
- probe_
media_ characteristics_ with_ options - Probes a file with additive expansion controls and returns the media-characteristics summary.
- probe_
media_ characteristics_ with_ options_ async async - Probes a file through the additive Tokio-based async surface with expansion controls and returns the media-characteristics summary.
- probe_
with_ options - Probes a file with additive expansion controls and returns the backwards-compatible coarse movie, track, and fragment summary.
- probe_
with_ options_ async async - Probes a file through the additive Tokio-based async surface with expansion controls and returns the backwards-compatible coarse movie, track, and fragment summary.